# The Prelude

This library can do the following:
1. Turn any code base into a security probe (Probe module)
2. Manage your Prelude Detect account (Account module)

## Probe module

### Setup
1. Use the Account module to register a new probe, which will return you a security token.
2. Set the token as an environment variable named PRELUDE_TOKEN (shown below).

### Usage guide

Add this snippet anywhere in your code base to start a probe.

```python
import os
from theprelude import detect
os.environ['PRELUDE_TOKEN'] = 'e7ae516464340bde42e61080ce3b1f57e7c5a150'
detect.Probe()
```

How it works:
- The probe is downloaded into the application's process space.
- It runs as long as the application is alive.

## Account module

### Setup

Create a ~/.prelude/keychain.ini file with your account info, such as:

```
[default]
hq=http://localhost:8080
account=a60ba00b4e1254cd5221cb77527190c6
token=65277d48-71d0-4f39-ad05-c581a51d7f82
secret=af3c199c2470cb477d907b1e0917c17a
```

### Usage guide

A basic use case for continuous security testing:

> Please review docstrings to see optional parameters and functions not shown here.

```python
from theprelude import detect

account = detect.Account(profile='default')
account.upload('/tmp/43b3754c-def4-4699-a673-1d85648fda6a.yml')
account.activate('43b3754c-def4-4699-a673-1d85648fda6a', detect.RunCode.CONTINUOUS)
token = account.register('host/1')
print('Start a probe anywhere with this token: %s' % token)
```

### Command line utility

There is a built-in command-line program that allows easy access to the Account module. You can use this as follows:
```python
from theprelude import detect
detect.Cli(profile='default').start()
```

## Developer guide

Make changes then install locally before testing:
```
pip install .
```

To publish a new version on [PyPy](https://pypi.org/project/theprelude/):
```commandline
python -m build
python -m twine upload --repository pypi dist/*
```
